#ifndef _DB_ACCESS_H_
#define _DB_ACCESS_H_

/*******************************************************/
/*  International Data Centre                          */
/*  Comprehensive Test Ban Treaty Organization         */
/*  Vienna                                             */
/*  Austria                                            */
/*******************************************************/

/**
 * @author    Gerald Klinkl
 *
 * Revision 1.27  2013-10-17 gerald
 * Add flag parameter to getFrameProduct()
 *
 * Revision 1.26  2013-07-05 gerald
 * Move 'getODBCProvider' to db_access.c
 *
 */

#include <pthread.h>
#include <sqltypes.h>
#include "cd_common.h"
#include "fileAPI.h"
#include "merge.h"


/* ==== Defines and data structure for DB access  =========================== */

#define CD_B10_FILE   0
#define CD_B11_FILE   1
#define CD_CLF_FILE   2
#define CD_TXT_FILE   3
#define CD_MWF_FILE   4


#define WFID_STRING     "wfid"
#define QUALID_STRING   "qualid"
#define FRID_STRING     "frid"

/* ==== Prototypes ========================================================== */

/*@only@*//*@null@*/ sensor_t *loadSensorFromDB(const char *appName,
                       SQLHDBC hdbc, /*@out@*/int *sensorTableCount,
                       time_t startDate, time_t endDate);

extern uint16_t loadWfdiscRecordsFromDB(station_t *pStation,
                                   uint32_t loadDate,
                                   waveFormHead_t *pWaveFormHead);
extern uint16_t loadQualityRecordsFromDB(station_t *pStation, uint32_t loadDate,
                waveFormHead_t *pWaveFormHead, uint32_t dayInWindow);
extern /*@null@*//*@shared@*/SQLHDBC getDBHandle();
extern int updateWfdiscInDB(SQLHDBC hdbc, int mode, const char *site,
                            const char *channel, double startTime,
                            long wfid, long channelID, long jDate,
                            double endTime, long samplesInReqSegment,
                            double sampleRate, float calib, float calper,
                            const char *insType, const char *dataType,
                            const char *clipped, const char *dir,
                            const char *dfile, long offset);
extern int updateQualityInDB(SQLHDBC hdbc, int mode, cdQuality_t *qr);
extern long getNextID(/*@null@*/SQLHDBC hdbc, const char *whatID,
                      configParams_t *pConfigData);
extern /*@null@*/SQLHDBC getDBhandle(const char *appName,
                                     senderParams_t *pSenderParams);
extern void raiseIDcache(const char *whatID);
extern void sqlDisconnect(SQLHDBC hdbc);
extern int deleteRecordInDB(SQLHDBC hdbc, long rid, int what);
#ifndef HAVE_LIBIDCODBC
extern int recycleIds(int *id, int sR, pthread_mutex_t *pAppMutex, int what);
#else
extern int recycleIds(long *id, int sR, pthread_mutex_t *pAppMutex, int what);
#endif
extern int commitChanges(SQLHDBC hdbc, configParams_t *pConfigData);
extern int updateFrameProduct(/*@null@*/HDBC hdbc, long frid, uint32_t size,
                              double time);
extern int insertClfInDB(SQLHDBC hdbc, intRefListParams_t *pCurrentFrame,
                         const char clfType, const uint32_t duration,
                         const int revision, const char *channelMask);

#define ONLY_QUERY   1  /**< only query the frameproduct table */
#define CREATE_ID    2  /**< create ID for the file if not exists in
                             the frameproduct table */
#define IGNORE_NONEXIST 3  /**< ignore if file does not exist */

extern long
getFrameProduct(HDBC hdbc, station_t *pStation, char *pathAndFile,
                int type, int mode, double startTime,
                /*@null@*//*@out@*/int *flag);
extern int setFpIDs(const char* fpIDs);
/*@observer@*/ extern const char *getODBCProvider();

#define QUERY_BUFFER_SIZE 512
#endif
