/*******************************************************/
/*  International Data Centre                          */
/*  Comprehensive Test Ban Treaty Organization         */
/*  Vienna                                             */
/*  Austria                                            */
/*******************************************************/

/**
 * @author    Gerald Klinkl
 *
 * Revision 1.5  2015-09-10 gerald
 * Set syslog ID as requested by EW
 *
 * Revision 1.4  2013-04-09 gerald
 * Support new idcsyslog public header filename (from cbase 1.1.0)
 *
 * Revision 1.3  2012-06-27 gerald
 * Fix function comment
 *
 * Revision 1.2  2010-03-04 12:39:38  gerald
 * Add more description to message API sample function
 *
 * Revision 1.1  2009-09-29 12:39:54  gerald
 * Message API added
 *
 */

#include <config.h>
#include <stdio.h>
#include <stdlib.h>
#include "messageAPI.h"

#ifdef HAVE_IDCSYSLOG_H
 #include "idcsyslog.h"
#else
 #include "logging.h" /* Deprecated */
#endif


/**
 * @short usage function
 *
 * @description This function informs the user about the allowed
 * @description command line parameters and exits the application
 *
 * @param app       name of application
 *
 * @return nothing
 */

static void
usage(const char *app)
{
   fprintf(stderr, "usage: %s config_file message_file\n", app);
   exit(EXIT_FAILURE);
}

/**
 * @short Sample message API main function
 *
 * @description This function initializes the message API and reads
 * @description an IMS2.0 message and passes it to the message API.
 * @description The message API converts the message into a binary frame.
 *
 * @param argc          argument count
 * @param argv          argument vector
 *
 * @return 0 on success or != 0 on error
 */

int
main(const int argc, const char *argv[])
{
   FILE *fp;
   int ret = 0;

   if (argc < 3) usage(argv[0]);

   /* Open the message file */
   fp = fopen(argv[2], "r");
   if (NULL == fp)
   {
       fprintf(stderr, "can't open %s\n", argv[2]);
       exit(EXIT_FAILURE);
   }

   /* Init syslog */
   logInit("ctbt.msgsys.messageAPI", LOG_INFO);

   /* Initialize the message API */
   (void) initMessageAPI(argv[1]);

   /* Call Message API */
   if (0 != messageAPI(fp, &ret))
   {
      fprintf(stderr, "can't process  %s, returncode %d\n", argv[2], ret);
      exit(EXIT_FAILURE);
   }
   exit(EXIT_SUCCESS);
}
